<?php
/*
Plugin Name: Extended Antispambot
Version: 1
Description: Obfuscation of email via the <code>[antispambot]...[/antispambot]</code> shortcode syntax using built-in <a href="http://codex.wordpress.org/Function_Reference/antispambot#Examples" target="_blank">Wordpress Codex</a> functionality. It works within widgets as well.
Author: Amit Mittal
Author URI:
Plugin URI: https://wordpress.org/plugins/antispambot-email
Text Domain: antispambot
*/

/**
 * Hide email from Spam Bots using a shortcode.
 *
 * @param array  $atts    Shortcode attributes. Not used.
 * @param string $content The shortcode content. Should be an email address.
 *
 * @return string The obfuscated email address. 
 */
if(!function_exists('wpex_antispambot_shortcode')) {
    function wpex_antispambot_shortcode($atts, $content = null)
    {
        $email = strtok($content, '?'); //allow e.g. ?subject=foo+bar&body=bif in email
        $urlpart = strtok('');
        if (strlen($urlpart) > 0) {
            $urlpart = '?' . $urlpart;
        }
        if (!is_email($email)) {
            return $content;
        }
        extract(shortcode_atts(array(
            'hex_encoding' => 0,
            'nolink' => false,
            'linktext' => false,
        ), $atts, 'antispambot'));

        add_filter('widget_text', 'do_shortcode');

        if ($nolink) {
            return antispambot($email, $hex_encoding);
        } else {
            $url = esc_url('mailto:' . antispambot($email, $hex_encoding) . $urlpart);
            if ($linktext) {
                return '<a href="' . $url . '">' . htmlspecialchars($linktext) . '</a>';
            } else {
                return '<a href="' . $url . '">' . antispambot($email, $hex_encoding) . '</a>';
            }
        }
    }

    add_shortcode('antispambot', 'wpex_antispambot_shortcode');
}